INTE Sites

## INTE Africa Sites: Tanzania

Select a site to continue

INTE Africa Sites: Tanzania
Home Bagamoyo District hospital 201 Buguruni Health Centre 202 Cardinal Rugambwa Hospital 203 Consolata Sisters Dispensary 204 Kinondoni Hospital 205 Kisarawe District Hospital 206 Magomeni Health Centre 207 Mbagala Rangi Tatu Hospital 208 Mnazi Mmoja Hospital 209 Sinza Hospital 210 St.Vincent Health Centre 211 Tambuka Reli Dispensary 212 Tandale Health Centre 213 Tegeta Mission Centre 214 Temeke Regional Referral Hospital 215 Yombo Vituka Health Centre 216